@@ -17,11 +17,10 @@ from __future__ import annotations
 
 from asyncio.log import logger
 from contextlib import AsyncExitStack
-import json
-from json.decoder import JSONDecodeError
 import pathlib
 from typing import AsyncIterable
 
+from bleak import BleakScanner
 from zeroconf.asyncio import AsyncZeroconf
 
 from aiohomekit.characteristic_cache import (
@@ -29,6 +28,7 @@ from aiohomekit.characteristic_cache import (
     CharacteristicCacheType,
 )
 from aiohomekit.controller.abstract import AbstractDiscovery
+import aiohomekit.hkjson as hkjson
 
 from ..const import (
     BLE_TRANSPORT_SUPPORTED,
@@ -43,15 +43,6 @@ from ..exceptions import (
 )
 from .abstract import AbstractController, AbstractPairing
 
-if COAP_TRANSPORT_SUPPORTED:
-    from aiohomekit.controller.coap.controller import CoAPController
-
-if IP_TRANSPORT_SUPPORTED:
-    from .ip import IpController
-
-if BLE_TRANSPORT_SUPPORTED:
-    from aiohomekit.controller.ble.controller import BleController
-
 
 class Controller(AbstractController):
     """
@@ -64,6 +55,7 @@ class Controller(AbstractController):
         self,
         async_zeroconf_instance: AsyncZeroconf | None = None,
         char_cache: CharacteristicCacheType | None = None,
+        bleak_scanner_instance: BleakScanner | None = None,
     ) -> None:
         """
         Initialize an empty controller. Use 'load_data()' to load the pairing data.
@@ -73,6 +65,7 @@ class Controller(AbstractController):
         super().__init__(char_cache=char_cache or CharacteristicCacheMemory())
 
         self._async_zeroconf_instance = async_zeroconf_instance
+        self._bleak_scanner_instance = bleak_scanner_instance
 
         self._transports: list[AbstractController] = []
         self._tasks = AsyncExitStack()
@@ -81,7 +74,11 @@ class Controller(AbstractController):
         self._transports.append(await self._tasks.enter_async_context(controller))
 
     async def async_start(self) -> None:
-        if IP_TRANSPORT_SUPPORTED:
+        if IP_TRANSPORT_SUPPORTED or self._async_zeroconf_instance:
+            from .ip.controller import (
+                IpController,  # pylint: disable=import-outside-toplevel
+            )
+
             await self._async_register_backend(
                 IpController(
                     char_cache=self._char_cache,
@@ -90,6 +87,10 @@ class Controller(AbstractController):
             )
 
         if COAP_TRANSPORT_SUPPORTED:
+            from .coap.controller import (
+                CoAPController,  # pylint: disable=import-outside-toplevel
+            )
+
             await self._async_register_backend(
                 CoAPController(
                     char_cache=self._char_cache,
@@ -97,9 +98,16 @@ class Controller(AbstractController):
                 )
             )
 
-        if BLE_TRANSPORT_SUPPORTED:
+        if BLE_TRANSPORT_SUPPORTED or self._bleak_scanner_instance:
+            from .ble.controller import (
+                BleController,  # pylint: disable=import-outside-toplevel
+            )
+
             await self._async_register_backend(
-                BleController(char_cache=self._char_cache)
+                BleController(
+                    char_cache=self._char_cache,
+                    bleak_scanner_instance=self._bleak_scanner_instance,
+                )
             )
 
     async def async_stop(self) -> None:
@@ -142,8 +150,8 @@ class Controller(AbstractController):
         :raises ConfigLoadingError: if the config could not be loaded. The reason is given in the message.
         """
         try:
-            with open(filename) as input_fp:
-                data = json.load(input_fp)
+            with open(filename, encoding="utf-8") as input_fp:
+                data = hkjson.loads(input_fp.read())
                 for pairing_id in data:
                     try:
                         self.load_pairing(pairing_id, data[pairing_id])
@@ -153,8 +161,8 @@ class Controller(AbstractController):
             raise ConfigLoadingError(
                 f'Could not open "{filename}" due to missing permissions'
             )
-        except JSONDecodeError:
-            raise ConfigLoadingError(f'Cannot parse "{filename}" as JSON file')
+        except hkjson.JSON_DECODE_EXCEPTIONS as e:
+            raise ConfigLoadingError(f'Cannot parse "{filename}" as JSON file') from e
         except FileNotFoundError:
             pass
 
@@ -175,8 +183,8 @@ class Controller(AbstractController):
             path.parent.mkdir(parents=True, exist_ok=True)
 
         try:
-            with open(filename, "w") as output_fp:
-                json.dump(data, output_fp, indent="  ")
+            with open(filename, mode="w", encoding="utf-8") as output_fp:
+                output_fp.write(hkjson.dumps_indented(data))
         except PermissionError:
             raise ConfigSavingError(
                 f'Could not write "{filename}" due to missing permissions'
@@ -206,15 +214,19 @@ class Controller(AbstractController):
 
         pairing = self.aliases[alias]
 
-        primary_pairing_id = pairing.pairing_data["iOSPairingId"]
-        await pairing.remove_pairing(primary_pairing_id)
-
-        await pairing.close()
-
-        self._char_cache.async_delete_map(primary_pairing_id)
-
+        # Remove the pairing from the controller first
+        # so that it stops getting updates that might
+        # trigger a disconnected event poll.
         self.aliases.pop(alias, None)
         pairing.controller.aliases.pop(alias, None)
 
         self.pairings.pop(pairing.id, None)
         pairing.controller.pairings.pop(pairing.id, None)
+
+        primary_pairing_id = pairing.pairing_data["iOSPairingId"]
+
+        await pairing.remove_pairing(primary_pairing_id)
+
+        await pairing.close()
+
+        self._char_cache.async_delete_map(primary_pairing_id)
